Machine class

Available extensions

Constructors

Machine()

Properties

current State
no setter
hashCode int
The hash code for this object.
no setterinherited
isRunning bool
no setter
isStopped bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange(void fn(State? previous, State? next)) → void

Available on Machine, provided by the MachineCallbacks extension

pstart<T, S extends ParameterizedState<T>>(S state, T data) → void
pstate<T>([String? label]) ParameterizedState<T>
ptransition<T>(Set<State> from, ParameterizedState<T> to, [String? label]) ParameterizedTransition<T>
start(SimpleState state) → void
state([String? label]) SimpleState
stop() → void
toString() String
A string representation of this object.
override
transition(Set<State> from, SimpleState to, [String? label]) SimpleTransition

Operators

operator ==(Object other) bool
The equality operator.
inherited