ParameterizedState<T> class

Inheritance
Available extensions

Properties

data → T
no setter
hashCode int
The hash code for this object.
no setterinherited
id int
finalinherited
label String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call() bool
inherited
guard(bool test(T data)) → void

Available on ParameterizedState<T>, provided by the ParameterizedStateGuards extension

nest(Machine machine, Ignition start(T data)) → void

Available on ParameterizedState<T>, provided by the ParameterizedStateNesting extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onEnter(void fn(T data)) → void

Available on ParameterizedState<T>, provided by the ParameterizedStateCallbacks extension

onExit(void fn(T data)) → void

Available on ParameterizedState<T>, provided by the ParameterizedStateCallbacks extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited