SimpleState class

Inheritance
Available extensions

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
finalinherited
label String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call() bool
inherited
guard(bool test()) → void

Available on SimpleState, provided by the SimpleStateGuards extension

nest(Machine machine, Ignition start()) → void

Available on SimpleState, provided by the SimpleStateNesting extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onEnter(void fn()) → void

Available on SimpleState, provided by the SimpleStateCallbacks extension

onExit(void fn()) → void

Available on SimpleState, provided by the SimpleStateCallbacks extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited