SimpleTransition class

Inheritance

Properties

from Set<State>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
label String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to SimpleState
finalinherited

Methods

call() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited