Transition<S extends State> class sealed

Implementers
Available extensions

Properties

from Set<State>
final
hashCode int
The hash code for this object.
no setterinherited
label String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to → S
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onTrigger(void fn(State previous, S next)) → void

Available on Transition<S>, provided by the TransitionCallbacks extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited